@@ -44,6 +44,8 @@ Foundation; version 2 of the licence.
 #include "wrappers.h"
 #include "threads.h"
 
+static unsigned int gbl_current_discid = 0;
+
 GList * gbl_disc_matches = NULL;
 gboolean track_format[100];
 
@@ -194,7 +196,9 @@ int main(int argc, char *argv[])
     return 0;
 }
 
-
+// scan the cdrom device for a disc
+// returns True if a disc is present and
+//   is different from the last time this was called
 bool check_disc(char * cdrom)
 {
     int fd;
@@ -275,6 +279,8 @@ bool check_disc(char * cdrom)
 
 void clear_widgets()
 {
+    gbl_current_discid = 0;
+
     // hide the widgets for multiple albums
     gtk_widget_hide(lookup_widget(win_main, "disc"));
     gtk_widget_hide(lookup_widget(win_main, "pick_disc"));
@@ -482,7 +488,9 @@ GList * lookup_disc(cddb_disc_t * disc)
     return gbl_matches;
 }
 
-
+// reads the TOC of a cdrom into a CDDB struct
+// returns the filled out struct
+// so we can send it over the internet to lookup the disc
 cddb_disc_t * read_disc(char * cdrom)
 {
     char logStr[1024];
@@ -674,6 +682,11 @@ cddb_disc_t * read_disc(char * cdrom)
     }
 #endif
     close(fd);
+    
+    /* These two lines from Nicolas Lveill
+    * "let us have a discid for each read disc" */
+    if (disc)
+        cddb_disc_calc_discid(disc);
 
     return disc;
 }
@@ -690,6 +703,8 @@ void update_tracklist(cddb_disc_t * disc)
     bool singleartist;
     char logStr[1024];
     
+    gbl_current_discid = cddb_disc_get_discid(disc);
+
     sprintf(logStr, "update_tracklist() disk '%s' '%s' '%s'\n", disc_artist, disc_title, disc_genre);
     debugLog(logStr);
     if (disc_artist != NULL)
@@ -756,12 +771,17 @@ void refresh(char * cdrom, int force)
         if (disc == NULL)
             return;
         
-        gtk_widget_set_sensitive(lookup_widget(win_main, "rip_button"), TRUE);
+        if (gbl_current_discid != cddb_disc_get_discid(disc))
+        {
+            /* only trash the user's inputs when the disc is new */
+            
+            gtk_widget_set_sensitive(lookup_widget(win_main, "rip_button"), TRUE);
         
-        // show the temporary info
-        gtk_entry_set_text(GTK_ENTRY(album_artist), "Unknown Artist");
-        gtk_entry_set_text(GTK_ENTRY(album_title), "Unknown Album");
-        update_tracklist(disc);
+            // show the temporary info
+            gtk_entry_set_text(GTK_ENTRY(album_artist), "Unknown Artist");
+            gtk_entry_set_text(GTK_ENTRY(album_title), "Unknown Album");
+            update_tracklist(disc);
+        }
         
         // clear out the previous list of matches
         /* this causes a segfault in the following scenario:
